//// Renames all selected layers with user-provided sequential label pattern. May get confused with certain folder structures. Not designed for negative numbers.
//// Released by Chance Miller without license or guarantee. http://www.middleendian.com/

// Function to add label to active layer
function addLabel() {
	if (pad_numbers) {
		docRef.activeLayer.name=prefix + (padding_string + main_index).substr(-padding_amount,padding_amount) + suffix;
	} else {
		docRef.activeLayer.name=prefix + main_index + suffix;
	}
	if (decrement) {
		main_index--;
	} else {
		main_index++;
	}
}


function main() {
	// Prompt user for label pattern. To change default values, change this file! Those locations marked with //*
	var layer_directions = ["Bottom to Top", "Top to Bottom"];
	var increment_decrement = ["Increment from:", "Decrement from:"];
	var dialog_window = new Window("dialog", "Frame Labeler");
	var top_to_bottom = true;
	decrement = true;
	padding_string = "";

	var incdec_dropdown = dialog_window.add("dropdownlist", undefined, increment_decrement);
	incdec_dropdown.minimumSize.width = 400;
	incdec_dropdown.selection = 0; //* Change number to 0 to increment by default, 1 to decrement by default

	var start_number = dialog_window.add("edittext", undefined, "0"); //* Change last quoted string to change default starting number. Make sure you enter a number! Otherwise defaults to zero.
	start_number.minimumSize.width = 400;

	var prefix_label = dialog_window.add("statictext", undefined, "Prefix:");
	var prefix_in = dialog_window.add("edittext", undefined, "frame"); //* Change the last quoted string to change the default prefix
	prefix_in.minimumSize.width = 400;

	var suffix_label = dialog_window.add("statictext", undefined, "Suffix:");
	var suffix_in = dialog_window.add("edittext", undefined, ""); //* Change the last quoted string to change the default suffix
	suffix_in.minimumSize.width = 400;

	var pad_checkbox = dialog_window.add("checkbox", undefined, "Pad numbers");
	pad_checkbox.value = true; //* Change this value between true and false to enable or disable padding by default
	var padding_in = dialog_window.add("edittext", undefined, "4"); //* Change last quoted string to change default padding amount. Make sure you enter a number! Otherwise defaults to zero.
	padding_in.minimumSize.width = 400;


	var direction_label = dialog_window.add("statictext", undefined, "Choose Layer Direction:");
	var direction_dropdown = dialog_window.add("dropdownlist", undefined, layer_directions);
	direction_dropdown.minimumSize.width = 400;
	direction_dropdown.selection = 0;  //* Change number to 0 to go bottom to top by default, 1 to go top to bottom by default

	dialog_window.add("button", undefined, "OK");
	var window_ok = dialog_window.show(); // returns 1 if OK is pressed or return/enter is pressed, 2 if escape is pressed or window closed somehow
	if (window_ok != 1) {
		return;
	}
	
	// Process user results
	pad_numbers = pad_checkbox.value;
	if (pad_numbers) {
		padding_amount = parseInt(padding_in.text);
		if (isNaN(padding_amount)) {
			pad_numbers = false;
		} else {
			for (var i = 0; i < padding_amount; i++) {
				padding_string += "0";
			}
		}
	}

	if (String(incdec_dropdown.selection) == String(increment_decrement[0])) {
		decrement = false;
	}

	if (String(direction_dropdown.selection) == String(layer_directions[0])) {
		top_to_bottom = false;
	}

	main_index = parseInt(start_number.text);
	if (isNaN(main_index)) {
		main_index = 0;
	}

	prefix = prefix_in.text;
	suffix = suffix_in.text;

	// Weird Photoshop nonsense to detect selected layers and store them in selected_layers array
	selected_layers=[];
	try {
		var idGrp = stringIDToTypeID( "groupLayersEvent" );
		var descGrp = new ActionDescriptor();
		var refGrp = new ActionReference();
		refGrp.putEnumerated(charIDToTypeID( "Lyr " ),charIDToTypeID( "Ordn" ),charIDToTypeID( "Trgt" ));
		descGrp.putReference(charIDToTypeID( "null" ), refGrp );
		executeAction( idGrp, descGrp, DialogModes.NO );
		for (var ix=0;ix<app.activeDocument.activeLayer.layers.length;ix++) {
			selected_layers.push(app.activeDocument.activeLayer.layers[ix]);
		}
		var id8 = charIDToTypeID( "slct" );
		var desc5 = new ActionDescriptor();
		var id9 = charIDToTypeID( "null" );
		var ref2 = new ActionReference();
		var id10 = charIDToTypeID( "HstS" );
		var id11 = charIDToTypeID( "Ordn" );
		var id12 = charIDToTypeID( "Prvs" );
		ref2.putEnumerated( id10, id11, id12 );
		desc5.putReference( id9, ref2 );
		executeAction( id8, desc5, DialogModes.NO );
	} catch (e) {}


	// Iterate through selected layers and add label as specified by user prompt
	if (app.documents.length>0) {
		docRef = activeDocument;
		if (top_to_bottom) {
			for (var i=0; i<selected_layers.length; i++) {
				docRef.activeLayer = selected_layers[i];
				if(!docRef.activeLayer.isBackgroundLayer){
					try{
						addLabel();
					} catch (e) {}
				}
			}
		} else {
			for (var i=selected_layers.length-1; i>=0; i--) {
				docRef.activeLayer = selected_layers[i];
				if(!docRef.activeLayer.isBackgroundLayer){
					try{
						addLabel();
					} catch (e) {}
				}
			}
		}
	} else {
		alert('There are no open files');
	};
}
main();
